aboutsummaryrefslogtreecommitdiffstats
path: root/core/agreement.go
diff options
context:
space:
mode:
Diffstat (limited to 'core/agreement.go')
-rw-r--r--core/agreement.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/core/agreement.go b/core/agreement.go
index 6727ecb..f2a9e3d 100644
--- a/core/agreement.go
+++ b/core/agreement.go
@@ -419,8 +419,8 @@ func (a *agreement) processVote(vote *types.Vote) error {
aID := a.agreementID()
// Agreement module has stopped.
if isStop(aID) {
- // Hacky way to not drop first votes for height 0.
- if vote.Position.Height == uint64(0) {
+ // Hacky way to not drop first votes for genesis height.
+ if vote.Position.Height == types.GenesisHeight {
a.pendingVote = append(a.pendingVote, pendingVote{
vote: vote,
receivedTime: time.Now().UTC(),